@@ -15,7 +15,6 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
-
 """
 Command line application wrapper over image builder.
 """
@@ -34,8 +33,6 @@ IMAGE_SIZE = '3800M'
 BUILD_MIRROR = 'http://deb.debian.org/debian'
 MIRROR = 'http://deb.debian.org/debian'
 DISTRIBUTION = 'unstable'
-DOWNLOAD_SOURCE = False
-INCLUDE_SOURCE = False
 BUILD_DIR = 'build'
 LOG_LEVEL = 'debug'
 HOSTNAME = 'freedombox'
@@ -45,6 +42,7 @@ logger = logging.getLogger(__name__)  # pylint: disable=invalid-name
 
 class Application(object):
     """Command line application to build FreedomBox images."""
+
     def __init__(self):
         """Initialize object."""
         self.arguments = None
@@ -84,58 +82,67 @@ class Application(object):
 
         parser = argparse.ArgumentParser(
             description='FreedomMaker - Script to build FreedomBox images',
-            formatter_class=argparse.ArgumentDefaultsHelpFormatter
-        )
+            formatter_class=argparse.ArgumentDefaultsHelpFormatter)
         parser.add_argument(
-            '--build-stamp', default=build_stamp,
+            '--build-stamp',
+            default=build_stamp,
             help='Build stamp to use on image file names')
         parser.add_argument(
-            '--image-size', default=IMAGE_SIZE,
+            '--image-size',
+            default=IMAGE_SIZE,
             help='Size of the image to build')
         parser.add_argument(
-            '--build-mirror', default=BUILD_MIRROR,
+            '--build-mirror',
+            default=BUILD_MIRROR,
             help='Debian mirror to use for building')
         parser.add_argument(
-            '--mirror', default=MIRROR,
+            '--mirror',
+            default=MIRROR,
             help='Debian mirror to use in built image')
         parser.add_argument(
-            '--distribution', default=DISTRIBUTION,
+            '--distribution',
+            default=DISTRIBUTION,
             help='Debian release to use in built image')
         parser.add_argument(
-            '--download-source', action='store_true', default=DOWNLOAD_SOURCE,
-            help='Whether to download source packages')
-        parser.add_argument(
-            '--include-source', action='store_true', default=INCLUDE_SOURCE,
-            help='Whether to include source in build image')
-        parser.add_argument(
-            '--package', action='append',
+            '--package',
+            action='append',
             help='Install additional packages in the image')
         parser.add_argument(
-            '--custom-package', action='append',
+            '--custom-package',
+            action='append',
             help='Install package from DEB file into the image')
         parser.add_argument(
-            '--build-dir', default=BUILD_DIR,
+            '--build-dir',
+            default=BUILD_DIR,
             help='Directory to build images and create log file')
         parser.add_argument(
-            '--log-level', default=LOG_LEVEL, help='Log level',
+            '--log-level',
+            default=LOG_LEVEL,
+            help='Log level',
             choices=('critical', 'error', 'warn', 'info', 'debug'))
         parser.add_argument(
-            '--hostname', default=HOSTNAME,
+            '--hostname',
+            default=HOSTNAME,
             help='Hostname to set inside the built images')
         parser.add_argument(
-            '--sign', action='store_true',
+            '--sign',
+            action='store_true',
             help='Sign the images with default GPG key after building')
         parser.add_argument(
-            '--force', action='store_true',
+            '--force',
+            action='store_true',
             help='Force rebuild of images even when required image exists')
         parser.add_argument(
-            '--build-in-ram', action='store_true',
+            '--build-in-ram',
+            action='store_true',
             help='Build the image in RAM so that it is faster, requires '
             'free RAM about the size of disk image')
-        parser.add_argument('--skip-compression', action='store_true',
-                            help='Do not compress the generated image')
-        parser.add_argument('targets', nargs='+',
-                            help='Image targets to build')
+        parser.add_argument(
+            '--skip-compression',
+            action='store_true',
+            help='Do not compress the generated image')
+        parser.add_argument(
+            'targets', nargs='+', help='Image targets to build')
 
         self.arguments = parser.parse_args()
 
