@@ -21,14 +21,13 @@ Base worker class to run various commands that build the image.
 import logging
 import os
 
-from . import internal
-from . import library
+from . import internal, library
 
+# initramfs-tools is a dependency for the kernel-image package. However, when
+# kernel is not installed, as in case of Raspberry Pi image, explicit dependency
+# is needed.
 BASE_PACKAGES = [
     'initramfs-tools',
-]
-
-NEXT_RELEASE_PACKAGES = [
     'firmware-ath9k-htc',
 ]
 
@@ -51,6 +50,8 @@ class ImageBuilder(object):  # pylint: disable=too-many-instance-attributes
     kernel_flavor = 'default'
     debootstrap_variant = None
 
+    extra_storage_size = '1000M'
+
     @classmethod
     def get_target_name(cls):
         """Return the command line name of target for this builder."""
@@ -59,7 +60,7 @@ class ImageBuilder(object):  # pylint: disable=too-many-instance-attributes
     @classmethod
     def get_builder_class(cls, target):
         """Return an builder class given target name."""
-        from . import builders # pylint: disable=unused-variable
+        from . import builders  # pylint: disable=unused-variable
 
         for subclass in cls.get_subclasses():
             if subclass.get_target_name() == target:
@@ -78,11 +79,6 @@ class ImageBuilder(object):  # pylint: disable=too-many-instance-attributes
         """Initialize object."""
         self.arguments = arguments
         self.packages = BASE_PACKAGES
-        if self.arguments.distribution in [
-                'unstable', 'testing', 'sid', 'buster'
-        ]:
-            self.packages += NEXT_RELEASE_PACKAGES
-
         self.ram_directory = None
 
         self.builder_backends = {}
