@@ -168,6 +168,11 @@ class InternalBuilderBackend():
             self.state, '/proc', 'proc', is_bind_mount=True)
         library.mount_filesystem(self.state, '/sys', 'sys', is_bind_mount=True)
 
+        # Kill all the processes on the / filesystem before attempting to
+        # unmount /dev/pts. Otherwise, unmounting /dev/pts will fail.
+        library.schedule_cleanup(self.state, library.process_cleanup,
+                                 self.state)
+
     def _get_packages(self):
         """Return the list of extra packages to install.
 
@@ -245,26 +250,14 @@ class InternalBuilderBackend():
     def _install_freedombox_packages(self):
         """Install custom .deb packages."""
         custom_freedombox = None
-        custom_plinth = None
-        custom_setup = None
         for package in (self.builder.arguments.custom_package or []):
-            if 'plinth_' in package:
-                custom_plinth = package
-            elif 'freedombox-setup_' in package:
-                custom_setup = package
-            elif 'freedombox_' in package:
+            if 'freedombox_' in package:
                 custom_freedombox = package
 
         if custom_freedombox:
             library.install_custom_package(self.state, custom_freedombox)
-
-        if custom_plinth:
-            library.install_custom_package(self.state, custom_plinth)
-
-        if custom_setup:
-            library.install_custom_package(self.state, custom_setup)
         else:
-            library.install_package(self.state, 'freedombox-setup')
+            library.install_package(self.state, 'freedombox')
 
     def _lock_root_user(self):
         """Lock the root user account."""
@@ -286,8 +279,8 @@ class InternalBuilderBackend():
         And that FreedomBox is not installed using a Debian package.
 
         """
-        library.run_in_chroot(self.state,
-                              ['mkdir', '-p', '/var/lib/freedombox'])
+        library.run_in_chroot(
+            self.state, ['mkdir', '-p', '-m', '755', '/var/lib/freedombox'])
         library.run_in_chroot(
             self.state,
             ['touch', '/var/lib/freedombox/is-freedombox-disk-image'])
