@@ -263,20 +263,25 @@ def mount_filesystem(state,
     run(['mount', device, mount_point] + options)
     state.setdefault('sub_mount_points', {})[label_or_path] = sub_mount_point
 
-    schedule_cleanup(state, unmount_filesystem, device, mount_point,
-                     is_bind_mount)
+    schedule_cleanup(state, unmount_filesystem, device, mount_point)
 
 
-def unmount_filesystem(device, mount_point, is_bind_mount, ignore_fail=False):
+def unmount_filesystem(device, mount_point, ignore_fail=False):
     """Unmount a filesystem."""
     logger.info('Unmounting device %s from mount point %s', device,
                 mount_point)
-    if not is_bind_mount:
-        run(['fuser', '-mvk', mount_point], ignore_fail=True)
-
     run(['umount', mount_point], ignore_fail=ignore_fail)
 
 
+def process_cleanup(state):
+    """Kill all processes using a given mount point."""
+    mount_point = state['mount_point']
+    logger.info('Killing all processes on the mount point %s', mount_point)
+    run(['fuser', '-mvk', mount_point], ignore_fail=True)
+    # XXX: Twice seems to work better?
+    run(['fuser', '-mvk', mount_point], ignore_fail=True)
+
+
 def setup_extra_storage(state, file_system_type, size):
     """Add an extra storage device to a btrfs filesystem."""
     if file_system_type != 'btrfs':
@@ -300,14 +305,25 @@ def cleanup_extra_storage(state, loop_device, extra_storage_file):
     mount_point = state['mount_point']
     logger.info('Removing extra storage from file system %s', mount_point)
 
+    _btrfs_rebalance(mount_point)
+    run(['btrfs', 'balance', 'start', '-mconvert=dup', mount_point],
+        ignore_fail=True)
+
     # Remove the extra storage device from btrfs filesystem
     run(['btrfs', 'device', 'remove', loop_device, mount_point])
     run(['losetup', '--detach', loop_device])
     run(['rm', '-f', extra_storage_file])
 
-    # Re-balance the filesystem
-    run(['btrfs', 'balance', 'start', '-musage=20', mount_point])
-    run(['btrfs', 'balance', 'start', '-dusage=20', mount_point])
+    _btrfs_rebalance(mount_point)
+
+
+def _btrfs_rebalance(mount_point):
+    """Re-balance btrfs filesystem."""
+    for usage in range(0, 100, 20):
+        run(['btrfs', 'balance', 'start', f'-musage={usage}', mount_point],
+            ignore_fail=True)
+        run(['btrfs', 'balance', 'start', f'-dusage={usage}', mount_point],
+            ignore_fail=True)
 
 
 def qemu_debootstrap(state, architecture, distribution, variant, components,
@@ -329,10 +345,7 @@ def qemu_debootstrap(state, architecture, distribution, variant, components,
             'Unmounting filesystems that may have been left by debootstrap')
         for path in ('proc', 'sys', 'etc/machine-id'):
             unmount_filesystem(
-                None,
-                os.path.join(target, path),
-                is_bind_mount=True,
-                ignore_fail=True)
+                None, os.path.join(target, path), ignore_fail=True)
         raise
 
     schedule_cleanup(state, qemu_remove_binary, state)
@@ -343,7 +356,6 @@ def qemu_debootstrap(state, architecture, distribution, variant, components,
         unmount_filesystem,
         None,
         os.path.join(target, 'etc/machine-id'),
-        is_bind_mount=True,
         ignore_fail=True)
 
 
