@@ -336,21 +336,22 @@ modify x x
     @patch('freedommaker.library.run')
     def test_unmount_filesystem(self, run):
         """Test unmounting a filesystem."""
-        library.unmount_filesystem('/dev/', self.state['mount_point'], False,
-                                   False)
+        library.unmount_filesystem('/dev/', self.state['mount_point'], False)
+        self.assertEqual(
+            run.call_args_list,
+            [call(['umount', self.state['mount_point']], ignore_fail=False)])
+
+    @patch('freedommaker.library.run')
+    def test_process_cleanup(self, run):
+        """Test cleaning up processes."""
+        library.process_cleanup(self.state)
         self.assertEqual(run.call_args_list, [
             call(['fuser', '-mvk', self.state['mount_point']],
                  ignore_fail=True),
-            call(['umount', self.state['mount_point']], ignore_fail=False)
+            call(['fuser', '-mvk', self.state['mount_point']],
+                 ignore_fail=True)
         ])
 
-        run.reset_mock()
-        library.unmount_filesystem('/dev/pts', self.state['mount_point'], True,
-                                   True)
-        self.assertEqual(
-            run.call_args_list,
-            [call(['umount', self.state['mount_point']], ignore_fail=True)])
-
     @patch('freedommaker.library.run')
     def test_setup_extra_storage(self, run):
         """Test that setting up extra storage works."""
@@ -371,10 +372,10 @@ modify x x
             call(['btrfs', 'device', 'add', loop_device, mount_point])
         ])
 
-        self.assertEqual(self.state['cleanup'], [
-            [library.cleanup_extra_storage, (self.state, loop_device,
-                                             extra_storage_file), {}]
-        ])
+        self.assertEqual(self.state['cleanup'], [[
+            library.cleanup_extra_storage,
+            (self.state, loop_device, extra_storage_file), {}
+        ]])
 
     @patch('freedommaker.library.run')
     def test_cleanup_extra_storage(self, run):
@@ -383,14 +384,55 @@ modify x x
         loop_device = self.random_string()
         mount_point = self.state['mount_point']
 
-        library.cleanup_extra_storage(self.state, loop_device, extra_storage_file)
+        library.cleanup_extra_storage(self.state, loop_device,
+                                      extra_storage_file)
 
         run.assert_has_calls([
+            call(['btrfs', 'balance', 'start', '-musage=0', mount_point],
+                 ignore_fail=True),
+            call(['btrfs', 'balance', 'start', '-dusage=0', mount_point],
+                 ignore_fail=True),
+            call(['btrfs', 'balance', 'start', '-musage=20', mount_point],
+                 ignore_fail=True),
+            call(['btrfs', 'balance', 'start', '-dusage=20', mount_point],
+                 ignore_fail=True),
+            call(['btrfs', 'balance', 'start', '-musage=40', mount_point],
+                 ignore_fail=True),
+            call(['btrfs', 'balance', 'start', '-dusage=40', mount_point],
+                 ignore_fail=True),
+            call(['btrfs', 'balance', 'start', '-musage=60', mount_point],
+                 ignore_fail=True),
+            call(['btrfs', 'balance', 'start', '-dusage=60', mount_point],
+                 ignore_fail=True),
+            call(['btrfs', 'balance', 'start', '-musage=80', mount_point],
+                 ignore_fail=True),
+            call(['btrfs', 'balance', 'start', '-dusage=80', mount_point],
+                 ignore_fail=True),
+            call(['btrfs', 'balance', 'start', '-mconvert=dup', mount_point],
+                 ignore_fail=True),
             call(['btrfs', 'device', 'remove', loop_device, mount_point]),
             call(['losetup', '--detach', loop_device]),
             call(['rm', '-f', extra_storage_file]),
-            call(['btrfs', 'balance', 'start', '-musage=20', mount_point]),
-            call(['btrfs', 'balance', 'start', '-dusage=20', mount_point])
+            call(['btrfs', 'balance', 'start', '-musage=0', mount_point],
+                 ignore_fail=True),
+            call(['btrfs', 'balance', 'start', '-dusage=0', mount_point],
+                 ignore_fail=True),
+            call(['btrfs', 'balance', 'start', '-musage=20', mount_point],
+                 ignore_fail=True),
+            call(['btrfs', 'balance', 'start', '-dusage=20', mount_point],
+                 ignore_fail=True),
+            call(['btrfs', 'balance', 'start', '-musage=40', mount_point],
+                 ignore_fail=True),
+            call(['btrfs', 'balance', 'start', '-dusage=40', mount_point],
+                 ignore_fail=True),
+            call(['btrfs', 'balance', 'start', '-musage=60', mount_point],
+                 ignore_fail=True),
+            call(['btrfs', 'balance', 'start', '-dusage=60', mount_point],
+                 ignore_fail=True),
+            call(['btrfs', 'balance', 'start', '-musage=80', mount_point],
+                 ignore_fail=True),
+            call(['btrfs', 'balance', 'start', '-dusage=80', mount_point],
+                 ignore_fail=True),
         ])
 
     @patch('freedommaker.library.run')
@@ -412,7 +454,6 @@ modify x x
                  library.unmount_filesystem,
                  (None, self.state['mount_point'] + '/etc/machine-id'),
                  {
-                     'is_bind_mount': True,
                      'ignore_fail': True
                  }
              ]])
